Learn R Programming

projmgr (version 0.1.2)

report_todo: Print to-do lists in RMarkdown friendly way

Description

Interprets list representation of to-do list, using HTML to format results in a highly readable and attractive way. Resulting object returned is a character vector of HTML code with the added class of 'knit_asis' so that when included in an RMarkdown document knitting to HTML, the results will be correctly rendered as HTML.

Usage

report_todo(todo, show_ratio = TRUE)

Value

Returns character string of HTML with class attribute to be correctly shown "as-is" in RMarkdown

Arguments

todo

List of to-do list, as returned by read_todo()

show_ratio

Boolean. Whether or not to report (# Closed Items / # Total Items) for each group as a ratio

Details

The resulting HTML unordered list (<ul>) is tagged with class 'report_todo' for custom CSS styling.

See Also

Other plans and todos: post_plan(), post_todo(), read_plan(), read_todo(), report_plan(), template_yaml()

Examples

Run this code
if (FALSE) {
# the following could be run in RMarkdown
todo_path <- system.file("extdata", "todo-ex.yml", package = "projmgr", mustWork = TRUE)
my_todo <- read_todo(todo_path)
report_todo(my_todo)
}

Run the code above in your browser using DataLab