Creates a four-bar waterfall diagram. Within the specified timeframe, shows initial,
newly opened, newly closed, and final open counts. Works with either issues or milestones,
as obtained by the get and parse functions.
viz_waterfall(
data,
start_date,
end_date,
start = "created_at",
end = "closed_at"
)ggplot object
Dataset, such as those representing issues or milestones (i.e. parse_issues() or
parse_milestones()). Must have state variable and variables to specify for
start and end
Character string in 'YYYY-MM-DD' form for first date to be considered (inclusive)
Character string in 'YYYY-MM-DD' form for last date to be considered (inclusive)
Unquoted variable name denoting issue start date
Unquoted variable name denoting issue end date
The following logic is used to classify issues:
Initial: start < start_date and (end > start_date or state == 'open')
Open: start >= start_date and start <= end_date
Closed: end >= start_date and end <= end_date
Final: start < end_date and (end > end_date or state == 'open')
The exact accuracy of the logic depends on filtering that has already been done to the dataset. Think carefully
about the population you wish to represent when getting your data.
Other issues:
get_issue_comments(),
get_issue_events(),
get_issues(),
parse_issue_comments(),
parse_issue_events(),
parse_issues(),
post_issue_update(),
post_issue(),
report_discussion(),
report_progress()
if (FALSE) {
viz_waterfall(milestones, '2017-01-01', '2017-03-31')
}
Run the code above in your browser using DataLab