By default, the start date is the issue's created_at date, and the end date is
the issue's closed_at date. However, either of these can be altered via the
start and end parameters since these dates might not be reflective of the
true timeframe (e.g. if issues are posted well in advance of work beginning.)
Unfinished tasks (where the value of the end variable is NA) are colored grey and
do not have dots on their bars. Unstarted tasks are dropped because user intent is ambiguous
in that case.